#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sisio.h>

void vasincr( inbuf, inlen, outbuf, outlen )

	char *	inbuf;
	int *	inlen;
	char *	outbuf;
	int *	outlen;

{
	int	start, number, length, perword, ier;

	number = *inlen - 0;
	memcpy( outbuf + 0, inbuf + 0, number);
	HTOCF( outbuf + 0, number / 4 );
	*outlen = 0 + ( *inlen - 0 );
}
